@@ -3,7 +3,7 @@
 This package contains various modules that should be generic and reused
 in web application, specially CRM-like applications.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, division
 
 from .util import url_for
 
