@@ -1,5 +1,10 @@
 /* Abilian namespace */
+(function(factory) {
+    'use strict';
+    define('AbilianWidget', ['AbilianNS', 'jquery'], factory);
+}
 (function(Abilian, $) {
+    'use strict';
 
     /**
      * Initialize application parameters. Must be called when all resources are
@@ -15,18 +20,28 @@
         widgetsCreators[name] = createFun;
     };
 
+    Abilian.getWidgetCreator = function(name) {
+        return widgetsCreators[name];
+    };
+
     /*
      * Initialiaze a single element.
      */
     Abilian.initJsWidget = function() {
-        var $this = $(this);
-        var creatorName = $this.data('init-with');
-        var params = $this.data('init-params');
+        var $this = $(this),
+            creatorName = $this.data('init-with'),
+            params = $this.data('init-params'),
+            creatorFunc = widgetsCreators[creatorName];
+
+        if (creatorFunc === undefined) {
+            throw new Error('Unknown widget constructor: "' + creatorName + '"');
+        }
 
         if (!(params instanceof Array)) {
             params = new Array(params);
         }
-        widgetsCreators[creatorName].apply($this, params);
+
+        creatorFunc.apply($this, params);
     };
 
     /*
@@ -34,14 +49,5 @@
      */
     Abilian.events.widgetsInitialized = 'widgets-initiliazed';
 
-    Abilian.registerWidgetCreator(
-        'select2',
-        function(params) {
-            var initParams = {
-                'containerCssClass': 'form-control'
-            };
-            $.extend(initParams, params);
-            this.select2(initParams);
-        });
-
-})(window.Abilian = window.Abilian || {}, jQuery);
+    return Abilian;
+}));
